@@ -12,7 +12,7 @@ use Path::Class qw( tempdir );
 extends 'AnyEvent::FTP::Server';
 
 # ABSTRACT: Test (non-blocking) ftp clients against a real FTP server
-our $VERSION = '0.15'; # VERSION
+our $VERSION = '0.16'; # VERSION
 
 
 has test_uri => (
@@ -69,6 +69,8 @@ sub create_ftpserver_ok (;$$)
 {
   my($context, $message) = @_;
   
+  my $ctx = context();
+
   my $uri = URI->new("ftp://127.0.0.1");
   
   $context //= 'Memory';
@@ -91,7 +93,6 @@ sub create_ftpserver_ok (;$$)
     
     if($ENV{AEF_DEBUG})
     {
-      my $ctx = context();
       $server->on_connect(sub {
         my $con = shift;
         $ctx->note("CONNECT");
@@ -110,7 +111,6 @@ sub create_ftpserver_ok (;$$)
           $ctx->note("DISCONNECT");
         });
       });
-      $ctx->release;
     }
     
     $server->on_connect(sub {
@@ -135,7 +135,6 @@ sub create_ftpserver_ok (;$$)
   
   $message //= "created FTP ($name) server at $uri";
 
-  my $ctx = context();
   $ctx->ok($error eq '', $message);
   $ctx->diag($error) if $error;
   $ctx->release;
@@ -504,7 +503,7 @@ Test::AnyEventFTPServer - Test (non-blocking) ftp clients against a real FTP ser
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
